@@ -8,6 +8,7 @@
 #include "ps-internal.h"
 #include "common.h"
 #include "config.h"
+#include "cleancall.h"
 
 #ifdef PS__MACOS
 #include <mach/mach_time.h>
@@ -16,6 +17,8 @@ extern struct mach_timebase_info PS_MACH_TIMEBASE_INFO;
 
 
 static const R_CallMethodDef callMethods[]  = {
+  CLEANCALL_METHOD_RECORD,
+
   /* System api */
   { "ps__os_type",            (DL_FUNC) ps__os_type,            0 },
   { "ps__pids",               (DL_FUNC) ps__pids,               0 },
@@ -28,9 +31,13 @@ static const R_CallMethodDef callMethods[]  = {
   { "ps__tty_size",           (DL_FUNC) ps__tty_size,           0 },
   { "ps__disk_partitions",    (DL_FUNC) ps__disk_partitions,    1 },
   { "ps__disk_usage",         (DL_FUNC) ps__disk_usage,         1 },
+  { "ps__disk_io_counters",   (DL_FUNC) ps__disk_io_counters,   0 },
+  { "ps__fs_info",            (DL_FUNC) ps__fs_info,            3 },
   { "ps__system_memory",      (DL_FUNC) ps__system_memory,      0 },
   { "ps__system_swap",        (DL_FUNC) ps__system_swap,        0 },
-
+  { "ps__list_apps",          (DL_FUNC) ps__list_apps,          0 },
+  { "ps__stat",               (DL_FUNC) ps__stat,               2 },
+  { "ps__mount_point",        (DL_FUNC) ps__mount_point,        1 },
   /* ps_handle API */
   { "psll_pid",          (DL_FUNC) psll_pid,          1 },
   { "psll_handle",       (DL_FUNC) psll_handle,       2 },
@@ -57,7 +64,7 @@ static const R_CallMethodDef callMethods[]  = {
   { "psll_suspend",      (DL_FUNC) psll_suspend,      1 },
   { "psll_resume",       (DL_FUNC) psll_resume,       1 },
   { "psll_terminate",    (DL_FUNC) psll_terminate,    1 },
-  { "psll_kill",         (DL_FUNC) psll_kill,         1 },
+  { "psll_kill",         (DL_FUNC) psll_kill,         2 },
   { "psll_num_fds",      (DL_FUNC) psll_num_fds,      1 },
   { "psll_open_files",   (DL_FUNC) psll_open_files,   1 },
   { "psll_interrupt",    (DL_FUNC) psll_interrupt,    3 },
@@ -67,10 +74,10 @@ static const R_CallMethodDef callMethods[]  = {
   { "psll_dlls",         (DL_FUNC) psll_dlls,         1 },
   { "psll_get_cpu_aff",  (DL_FUNC) psll_get_cpu_aff,  1 },
   { "psll_set_cpu_aff",  (DL_FUNC) psll_set_cpu_aff,  2 },
+  { "psll_wait",         (DL_FUNC) psll_wait,         2 },
 
   /* Utils */
   { "ps__init",          (DL_FUNC) ps__init,          2 },
-  { "ps__kill_if_env",   (DL_FUNC) ps__kill_if_env,   4 },
   { "ps__find_if_env",   (DL_FUNC) ps__find_if_env,   3 },
   { "ps__inet_ntop",     (DL_FUNC) ps__inet_ntop,     2 },
   { "ps__memory_maps",   (DL_FUNC) ps__memory_maps,   1 },
@@ -85,10 +92,14 @@ static const R_CallMethodDef callMethods[]  = {
   { NULL, NULL, 0 }
 };
 
+int ps_pidfd_open_support = PS_MAYBE;
+
 /*
  * Called on module import on all platforms.
  */
 void R_init_ps(DllInfo *dll) {
+  cleancall_init();
+
   if (getenv("R_PS_DEBUG") != NULL) PS__DEBUG = 1;
   if (getenv("R_PS_TESTING") != NULL) PS__TESTING = 1;
 
